@@ -30,7 +30,7 @@
 
 using namespace Akonadi;
 
-class TrashRestoreJob::TrashRestoreJobPrivate : public JobPrivate
+class Akonadi::TrashRestoreJobPrivate : public JobPrivate
 {
 public:
     explicit TrashRestoreJobPrivate(TrashRestoreJob *parent)
@@ -59,7 +59,7 @@ public:
     QHash<Collection, Item::List> restoreCollections; // groups items to target restore collections
 };
 
-void TrashRestoreJob::TrashRestoreJobPrivate::selectResult(KJob *job)
+void TrashRestoreJobPrivate::selectResult(KJob *job)
 {
     Q_Q(TrashRestoreJob);
     if (job->error()) {
@@ -73,7 +73,7 @@ void TrashRestoreJob::TrashRestoreJobPrivate::selectResult(KJob *job)
     }
 }
 
-void TrashRestoreJob::TrashRestoreJobPrivate::targetCollectionFetched(KJob *job)
+void TrashRestoreJobPrivate::targetCollectionFetched(KJob *job)
 {
     Q_Q(TrashRestoreJob);
 
@@ -147,7 +147,7 @@ void TrashRestoreJob::TrashRestoreJobPrivate::targetCollectionFetched(KJob *job)
     }
 }
 
-void TrashRestoreJob::TrashRestoreJobPrivate::itemsReceived(const Akonadi::Item::List &items)
+void TrashRestoreJobPrivate::itemsReceived(const Akonadi::Item::List &items)
 {
     Q_Q(TrashRestoreJob);
     if (items.isEmpty()) {
@@ -197,7 +197,7 @@ void TrashRestoreJob::TrashRestoreJobPrivate::itemsReceived(const Akonadi::Item:
     }
 }
 
-void TrashRestoreJob::TrashRestoreJobPrivate::collectionsReceived(const Akonadi::Collection::List &collections)
+void TrashRestoreJobPrivate::collectionsReceived(const Akonadi::Collection::List &collections)
 {
     Q_Q(TrashRestoreJob);
     if (collections.isEmpty()) {
@@ -244,7 +244,7 @@ void TrashRestoreJob::TrashRestoreJobPrivate::collectionsReceived(const Akonadi:
     });
 }
 
-void TrashRestoreJob::TrashRestoreJobPrivate::removeAttribute(const Akonadi::Collection::List &list)
+void TrashRestoreJobPrivate::removeAttribute(const Akonadi::Collection::List &list)
 {
     Q_Q(TrashRestoreJob);
     QVectorIterator<Collection> i(list);
@@ -268,7 +268,7 @@ void TrashRestoreJob::TrashRestoreJobPrivate::removeAttribute(const Akonadi::Col
     }
 }
 
-void TrashRestoreJob::TrashRestoreJobPrivate::removeAttribute(const Akonadi::Item::List &list)
+void TrashRestoreJobPrivate::removeAttribute(const Akonadi::Item::List &list)
 {
     Q_Q(TrashRestoreJob);
     Item::List items = list;
