@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CACHECLEANER_H
-#define AKONADI_CACHECLEANER_H
+#pragma once
 
 #include "collectionscheduler.h"
 
@@ -75,4 +74,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
