@@ -8,11 +8,11 @@
 #include "akdebug.h"
 #include "akremotelog.h"
 
-#include <private/instance_p.h>
 #include <akonadifull-version.h>
+#include <private/instance_p.h>
 
-#include <QTimer>
 #include <QCoreApplication>
+#include <QTimer>
 
 #include <iostream>
 
@@ -52,7 +52,7 @@ void AkApplicationBase::init()
     }
 
     // there doesn't seem to be a signal to indicate that the session bus went down, so lets use polling for now
-    QTimer *timer = new QTimer(this);
+    auto timer = new QTimer(this);
     connect(timer, &QTimer::timeout, this, &AkApplicationBase::pollSessionBus);
     timer->start(10 * 1000);
 }
@@ -68,8 +68,7 @@ void AkApplicationBase::parseCommandLine()
                                             QStringLiteral("Namespace for starting multiple Akonadi instances in the same user session"),
                                             QStringLiteral("name"));
     mCmdLineParser.addOption(instanceOption);
-    const QCommandLineOption verboseOption(QStringLiteral("verbose"),
-                                           QStringLiteral("Make Akonadi very chatty"));
+    const QCommandLineOption verboseOption(QStringLiteral("verbose"), QStringLiteral("Make Akonadi very chatty"));
     mCmdLineParser.addOption(verboseOption);
 
     mCmdLineParser.process(QCoreApplication::arguments());
