@@ -5,12 +5,12 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AKONADI_TAGSELECTIONCOMBO_H
-#define AKONADI_TAGSELECTIONCOMBO_H
+#pragma once
 
 #include "akonadiwidgets_export.h"
 
-#include "tag.h"
+// AkonadiCore
+#include <akonadi/tag.h>
 
 #include <QComboBox>
 
@@ -18,6 +18,8 @@
 
 namespace Akonadi
 {
+class TagSelectionComboBoxPrivate;
+
 /**
  * @brief The TagSelectionCombo class
  */
@@ -46,10 +48,8 @@ Q_SIGNALS:
     void selectionChanged(const Akonadi::Tag::List &selection);
 
 private:
-    class Private;
-    std::unique_ptr<Private> const d;
+    std::unique_ptr<TagSelectionComboBoxPrivate> const d;
 };
 
 } // namespace
 
-#endif // TAGSELECTIONCOMBO_H
